==> haskell-ed25519-0.0.5.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ed25519
version: 0.0.5.0
id: ed25519-0.0.5.0-9NT4KzgzBhXCnbKiU3eJSo
key: ed25519-0.0.5.0-9NT4KzgzBhXCnbKiU3eJSo
license: MIT
copyright: Copyright (c) Austin Seipp 2013-2015
maintainer: Austin Seipp <aseipp@pobox.com>
homepage: http://thoughtpolice.github.com/hs-ed25519
synopsis: Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.
category: Cryptography
author: Austin Seipp
exposed: True
indefinite: False
exposed-modules:
    Crypto.Sign.Ed25519
abi: fd27f601ab70fec75cd9603479d6a7ac
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/ed25519-0.0.5.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/ed25519-0.0.5.0
hs-libraries: HSed25519-0.0.5.0-9NT4KzgzBhXCnbKiU3eJSo
depends:
    ghc-prim-0.5.1.0 base-4.10.0.0 bytestring-0.10.8.2
abi-depends: ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html: /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ed25519-0.0.5.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ed25519.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ed25519
version: 0.0.5.0
id: ed25519-0.0.5.0-5pFksGKabcUIJjOzH2huYw
key: ed25519-0.0.5.0-5pFksGKabcUIJjOzH2huYw
license: MIT
copyright: Copyright (c) Austin Seipp 2013-2015
maintainer: Austin Seipp <aseipp@pobox.com>
homepage: http://thoughtpolice.github.com/hs-ed25519
synopsis: Ed25519 cryptographic signatures
description:
    This package provides a simple, fast, self-contained copy of the
    Ed25519 public-key signature system with a clean interface. It also
    includes support for detached signatures, and thorough documentation
    on the design and implementation, including usage guidelines.
category: Cryptography
author: Austin Seipp
exposed: True
indefinite: False
exposed-modules:
    Crypto.Sign.Ed25519
abi: 4438940d31b53735299679370e6a50a4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ed25519-0.0.5.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/ed25519-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/ed25519-0.0.5.0
hs-libraries: HSed25519-0.0.5.0-5pFksGKabcUIJjOzH2huYw
depends:
    ghc-prim-0.5.1.1 base-4.10.1.0 bytestring-0.10.8.2
abi-depends: ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-ed25519/html/ed25519.haddock
haddock-html: /usr/share/doc/haskell-ed25519/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
